#ifndef NT2_INCLUDE_FUNCTIONS_COMMA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMMA_HPP_INCLUDED

#include <nt2/operator/include/functions/comma.hpp>

#endif
